@@ -3,11 +3,12 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.8.5 (default, Sep  4 2020, 07:30:14)  [GCC 7.3.0]
+# Python 3.8.8 (default, Feb 24 2021, 21:46:12)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
 #   ('--no-versions', '')
+#   ('--no-warnings', '')
 #   ('--silence', '')
 #   ('--member-specs', 'list')
 #   ('-f', '')
@@ -19,7 +20,7 @@
 #   tests/anonymous_type.xsd
 #
 # Command line:
-#   generateDS.py --no-dates --no-versions --silence --member-specs="list" -f -o "tests/anonymous_type2_sup.py" -s "tests/anonymous_type2_sub.py" --super="anonymous_type2_sup" tests/anonymous_type.xsd
+#   generateDS.py --no-dates --no-versions --no-warnings --silence --member-specs="list" -f -o "tests/anonymous_type2_sup.py" -s "tests/anonymous_type2_sub.py" --super="anonymous_type2_sup" tests/anonymous_type.xsd
 #
 # Current working directory (os.getcwd()):
 #   generateds
@@ -231,7 +232,7 @@ except ModulenotfoundExp_ as exp:
                 try:
                     int(value)
                 except (TypeError, ValueError):
-                    raise_parse_error(node, 'Requires sequence of integer valuess')
+                    raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
             return ('%.15f' % input_data).rstrip('0')
@@ -293,7 +294,7 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of decimal values')
             return values
         def gds_format_double(self, input_data, input_name=''):
-            return '%e' % input_data
+            return '%s' % input_data
         def gds_parse_double(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -791,7 +792,10 @@ def find_attr_value_(attr_name, node):
         value = attrs.get(attr_name)
     elif len(attr_parts) == 2:
         prefix, name = attr_parts
-        namespace = node.nsmap.get(prefix)
+        if prefix == 'xml':
+            namespace = 'http://www.w3.org/XML/1998/namespace'
+        else:
+            namespace = node.nsmap.get(prefix)
         if namespace is not None:
             value = attrs.get('{%s}%s' % (namespace, name, ))
     return value
@@ -1177,8 +1181,7 @@ class FooType(GeneratedsSuper):
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
         self.FooType = FooType_member
-        if self.FooType is not None:
-            self.validate_FooTypeType(self.FooType)
+        self.validate_FooTypeType(self.FooType)
         self.FooType_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
@@ -1296,8 +1299,7 @@ class BarType(GeneratedsSuper):
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
         self.BarType = BarType_member
-        if self.BarType is not None:
-            self.validate_BarTypeType(self.BarType)
+        self.validate_BarTypeType(self.BarType)
         self.BarType_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
@@ -1415,8 +1417,7 @@ class BazType(GeneratedsSuper):
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
         self.BazType = BazType_member
-        if self.BazType is not None:
-            self.validate_BazTypeType(self.BazType)
+        self.validate_BazTypeType(self.BazType)
         self.BazType_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
