@@ -1197,6 +1197,38 @@ class GenTest(unittest.TestCase):
         #self.remove('{}2_sub.py'.format(t_))
         #self.remove('{}2_out.xml'.format(t_))
 
+    def test_046_simpletype_list(self):
+        cmdTempl = (
+            'python3 generateDS.py --no-dates --no-versions '
+            '--member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            '--external-encoding="utf-8" '
+            '--export="write validate" '
+            'tests/%s.xsd'
+        )
+        t_ = 'simpletype_list'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        self.executeClean(cmd)
+        self.compareFiles(
+            '{}1_sup.py'.format(t_),
+            '{}2_sup.py'.format(t_),
+            ('sys.stdout.write',))
+        self.compareFiles('{}1_sub.py'.format(t_), '{}2_sub.py'.format(t_))
+        cmdTempl = (
+            'python3 tests/%s2_sup.py tests/%s.xml > tests/%s2_out.xml '
+            '2> tests/%s2_warnings.txt'
+        )
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        self.executeClean(cmd)
+        self.compareFiles(
+            '{}1_out.xml'.format(t_), '{}2_out.xml'.format(t_))
+        self.compareFiles(
+            '{}1_warnings.txt'.format(t_), '{}2_warnings.txt'.format(t_))
+        # cleanup generated files
+        self.remove('{}2_out.xml'.format(t_))
+        self.remove('{}2_warnings.txt'.format(t_))
+
     def compareFiles(self, left, right, ignore=None):
         left = os.path.join(TEST_DIR, left)
         right = os.path.join(TEST_DIR, right)
@@ -1226,7 +1258,7 @@ def strip_build_comments(lines):
     # Rstrip all the whitespace characters
     lines = [line.rstrip() + '\n' for line in lines]
 
-    if '#!/usr/bin/env python' in lines[0]:
+    if lines and '#!/usr/bin/env python' in lines[0]:
 
         # This line contains sometimes package version
         n = 3 + int('coding: utf-8' in lines[1])
